@@ -283,7 +283,46 @@ glade_marshal_OBJECT__OBJECT_UINT (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT (./glade-marshallers.list:8) */
+/* BOOLEAN:STRING (./glade-marshallers.list:8) */
+void
+glade_marshal_BOOLEAN__STRING (GClosure     *closure,
+                               GValue       *return_value,
+                               guint         n_param_values,
+                               const GValue *param_values,
+                               gpointer      invocation_hint,
+                               gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__STRING) (gpointer     data1,
+                                                    gpointer     arg_1,
+                                                    gpointer     data2);
+  register GMarshalFunc_BOOLEAN__STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__STRING) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_string (param_values + 1),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* BOOLEAN:OBJECT (./glade-marshallers.list:9) */
 void
 glade_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                GValue       *return_value,
@@ -322,7 +361,7 @@ glade_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:BOXED (./glade-marshallers.list:9) */
+/* BOOLEAN:BOXED (./glade-marshallers.list:10) */
 void
 glade_marshal_BOOLEAN__BOXED (GClosure     *closure,
                               GValue       *return_value,
@@ -361,7 +400,7 @@ glade_marshal_BOOLEAN__BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,POINTER (./glade-marshallers.list:10) */
+/* BOOLEAN:OBJECT,POINTER (./glade-marshallers.list:11) */
 void
 glade_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
                                        GValue       *return_value,
@@ -402,7 +441,7 @@ glade_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,BOOLEAN (./glade-marshallers.list:11) */
+/* BOOLEAN:OBJECT,BOOLEAN (./glade-marshallers.list:12) */
 void
 glade_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
                                        GValue       *return_value,
@@ -443,7 +482,7 @@ glade_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,UINT (./glade-marshallers.list:12) */
+/* BOOLEAN:OBJECT,UINT (./glade-marshallers.list:13) */
 void
 glade_marshal_BOOLEAN__OBJECT_UINT (GClosure     *closure,
                                     GValue       *return_value,
@@ -484,7 +523,7 @@ glade_marshal_BOOLEAN__OBJECT_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,OBJECT (./glade-marshallers.list:13) */
+/* BOOLEAN:OBJECT,OBJECT (./glade-marshallers.list:14) */
 void
 glade_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                       GValue       *return_value,
@@ -525,7 +564,48 @@ glade_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* STRING:OBJECT (./glade-marshallers.list:14) */
+/* BOOLEAN:OBJECT,STRING (./glade-marshallers.list:15) */
+void
+glade_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
+                                      GValue       *return_value,
+                                      guint         n_param_values,
+                                      const GValue *param_values,
+                                      gpointer      invocation_hint,
+                                      gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT_STRING) (gpointer     data1,
+                                                           gpointer     arg_1,
+                                                           gpointer     arg_2,
+                                                           gpointer     data2);
+  register GMarshalFunc_BOOLEAN__OBJECT_STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__OBJECT_STRING) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_object (param_values + 1),
+                       g_marshal_value_peek_string (param_values + 2),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* STRING:OBJECT (./glade-marshallers.list:16) */
 void
 glade_marshal_STRING__OBJECT (GClosure     *closure,
                               GValue       *return_value,
